Coverage for C:\src\imod-python\imod\flow\evt.py: 100%

1 from imod.flow.pkgbase import TopBoundaryCondition

2

3

4 class EvapoTranspiration(TopBoundaryCondition):

5 """

6 Recharge provides a fixed flux boundary condition to the top layer of the

7 groundwater system. Note that unlike in iMOD-WQ, there is only the option

8 in iMODFLOW to apply the recharge package to the top layer.

9

10 Parameters

11 ----------

12 rate: float or xr.DataArray of floats

13 evaporation rate in mm/day (NOTA BENE!), dims ``("time", "y", "x")``.

14 top_elevation: floats or xr.DataArray of floats

15 Top elevation in m+MSL for maximal evapotranspiration strength.

16 extinction_depth: float or xr.Datarray of floats

17 Depth [m] in which evapotranspiration strength reduced to zero.

18 """

19

20 _pkg_id = "evt"

21 _variable_order = ["rate", "top_elevation", "extinction_depth"]

22

23 def __init__(self, rate, top_elevation, extinction_depth):

24 super().__init__()

25 self.dataset["rate"] = rate

26 self.dataset["top_elevation"] = top_elevation

27 self.dataset["extinction_depth"] = extinction_depth